==> ad_suyi_flutter_sdk-0.0.1.tar.gz: android/src/main/kotlin/com/sangshen/ad_suyi_flutter_sdk/FlutterSplashAd.java <==
package com.sangshen.ad_suyi_flutter_sdk;

import android.widget.FrameLayout;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import io.flutter.plugin.platform.PlatformView;

public class FlutterSplashAd extends FlutterAd implements FlutterDestroyableAd {
    @NonNull
    private final AdInstanceManager manager;
    /**
     * 广告位id
     */
    @NonNull
    private final String adPosId;

    static class Builder {
        @Nullable
        private AdInstanceManager manager;
        @Nullable
        private String adPosId;

        public Builder setManager(@NonNull AdInstanceManager manager) {
            this.manager = manager;
            return this;
        }

        public Builder setAdPosId(@NonNull String adPosId) {
            this.adPosId = adPosId;
            return this;
        }

        FlutterSplashAd build() {
            if (manager == null) {
                throw new IllegalStateException("AdInstanceManager cannot not be null.");
            } else if (adPosId == null) {
                throw new IllegalStateException("adPosId cannot not be null.");
            }

            final FlutterSplashAd bannerAd = new FlutterSplashAd(manager, adPosId);
            return bannerAd;
        }
    }

    private FlutterSplashAd(
            @NonNull AdInstanceManager manager, @NonNull String adPosId) {
        this.manager = manager;
        this.adPosId = adPosId;
    }

    @Override
    void load() {
        SplashAdActivity.startActivity(manager.activity, manager, manager.adIdFor(this), adPosId);
    }

    @Override
    public void release() {

    }
}

==> ad_suyi_flutter_sdk-1.0.2.tar.gz: android/src/main/kotlin/com/sangshen/ad_suyi_flutter_sdk/FlutterSplashAd.java <==
package com.sangshen.ad_suyi_flutter_sdk;

import android.widget.FrameLayout;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import io.flutter.plugin.platform.PlatformView;

public class FlutterSplashAd extends FlutterAd implements FlutterDestroyableAd {
    @NonNull
    private final AdInstanceManager manager;
    /**
     * 广告位id
     */
    @NonNull
    private final String adPosId;
    /**
     * 背景图片
     */
    private final String imgName;
    /**
     * Logo图片
     */
    private final String imgLogoName;

    static class Builder {
        @Nullable
        private AdInstanceManager manager;
        @Nullable
        private String adPosId;

        private String imgName;

        private String imgLogoName;

        public Builder setManager(@NonNull AdInstanceManager manager) {
            this.manager = manager;
            return this;
        }

        public Builder setAdPosId(@NonNull String adPosId) {
            this.adPosId = adPosId;
            return this;
        }

        public Builder setImgName(@NonNull String imgName) {
            this.imgName = imgName;
            return this;
        }

        public Builder setImgLogoName(@NonNull String imgLogoName) {
            this.imgLogoName = imgLogoName;
            return this;
        }

        FlutterSplashAd build() {
            if (manager == null) {
                throw new IllegalStateException("AdInstanceManager cannot not be null.");
            } else if (adPosId == null) {
                throw new IllegalStateException("adPosId cannot not be null.");
            }

            final FlutterSplashAd bannerAd = new FlutterSplashAd(manager, adPosId, imgName, imgLogoName);
            return bannerAd;
        }
    }

    private FlutterSplashAd(
            @NonNull AdInstanceManager manager, @NonNull String adPosId, String imgName, String imgLogoName) {
        this.manager = manager;
        this.adPosId = adPosId;
        this.imgName = imgName;
        this.imgLogoName = imgLogoName;
    }

    @Override
    void load() {
        SplashAdActivity.startActivity(manager.activity, manager, manager.adIdFor(this), adPosId, imgName, imgLogoName);
    }

    @Override
    public void release() {

    }
}
